def add_one(number):
    """
    Add one to the given number.
    
    Args:
        number (int): The number to add one to.
        
    Returns:
        int: The number plus one.
    """
    return number + 1 